Pattern

Struct Pattern 

pub struct Pattern<M>(/* private fields */);
A collection of events with timing information.

Patterns can be created using the sequence and parallel functions. Patterns can be turned into flat sequences of events using Pattern::into_iter. See the module level documentation for more.