pub struct NodeSet { /* private fields */ }Expand description
Set a node’s control value(s).
Takes a list of pairs of control IDs and values and sets the controls to those values. If the node is a group, then it sets the controls of every node in the group.
Implementations
Sourceimpl NodeSet
impl NodeSet
Sourcepub fn new<C>(node_id: i32, controls: impl IntoIterator<Item = C>) -> NodeSetwhere
C: Into<ControlRange>,
pub fn new<C>(node_id: i32, controls: impl IntoIterator<Item = C>) -> NodeSetwhere
C: Into<ControlRange>,
Creates a new NodeSet command.
Arguments
node_id- The ID of the node that this command will affect.controls- Controls to set on the synth.
Each item in controls can be one of the following types:
Control- a control index or name and a value.ControlRange- a starting index or name and a range of values. The values are applied sequentially starting at the indexed or named control.