pub enum Error {
BadTypeID(i32),
IO(Error),
}Expand description
The error type of decoding operations.
Variants
BadTypeID(i32)
An error indiciating that the type ID field of the synth definition file was invalid.
The value inside the variant is the unexpected type ID that was read.
IO(Error)
An I/O error that occurred wile decoding the synth definition.